# -*- mode: python; coding: utf-8 -*-
# Copyright (C) 2017-2019 by BDE ENS Paris-Saclay
# SPDX-License-Identifier: GPL-3.0-or-later

import json
import urllib.request

from django.forms import ModelForm

from .models import Emprunt


class EmpruntForm(ModelForm):
    class Meta:
        model = Emprunt
        fields = ['media']


class MediaAdminForm(ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        isbn_field = self.fields.get('isbn')
        if isbn_field:
            isbn_field.widget.template_name = "media/isbn_button.html"
            isbn_field.widget.attrs.update({'autofocus': 'autofocus'})

    def download_data(self, isbn):
        """
        Download data from ISBN
        """
        api_url = "https://openlibrary.org/api/books?bibkeys=ISBN:{}" \
                  "&format=json&jscmd=data".format(isbn)
        with urllib.request.urlopen(api_url) as url:
            data = json.loads(url.read().decode())
        if data and data['ISBN:' + isbn]:
            data = data['ISBN:' + isbn]

            # Fill the data
            # TODO implement authors, side_identifier
            if 'title' in data:
                self.cleaned_data['title'] = data['title']
            if 'subtitle' in data:
                self.cleaned_data['subtitle'] = data['subtitle']
            if 'url' in data:
                self.cleaned_data['external_url'] = data['url']
            if 'number_of_pages' in data:
                self.cleaned_data['number_of_pages'] = \
                    data['number_of_pages']

    def clean(self):
        """
        If user fetch ISBN data, then download data before validating the form
        """
        if "_continue" in self.request.POST:
            isbn = self.cleaned_data.get('isbn')
            if isbn:
                # ISBN is present
                self.download_data(isbn)

        return super().clean()
